@@ -13,7 +13,7 @@ use PDL::Lite '2.012';
 
 ## no critic (ProhibitExplicitReturnUndef)
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use parent 'Statistics::Descriptive::PDL';
 
@@ -355,9 +355,8 @@ sub _geometric_mean {
 
     my $wts = $self->_get_weights_piddle;
 
-    my $exponent = 1 / $self->sum_weights;
-    my $powered = ($data * $wts) ** $exponent;
-    return $powered->dprodover;
+    # formula from https://en.wikipedia.org/wiki/Weighted_geometric_mean
+    return (($data->log * $wts)->sum / $wts->sum)->exp
 }
 
 sub _mode {
